summaryrefslogtreecommitdiff
path: root/framework/source/jobs/jobexecutor.cxx
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
committerThomas Arnhold <thomas@arnhold.org>2013-04-15 04:49:39 +0200
commit60fbefc615f8931bf8b952293fc4eb4ac35dafd8 (patch)
tree2a91fcbcb206d60dcc652a336bb9b6813578815e /framework/source/jobs/jobexecutor.cxx
parent7f71ed1c62775a4e5b2efebf55f284a5c32b2df4 (diff)
fdo#60724 informations -> information
Change-Id: Ifd34ebfc7fe01b4a470eb072597dd3ec97c97863
Diffstat (limited to 'framework/source/jobs/jobexecutor.cxx')
-rw-r--r--framework/source/jobs/jobexecutor.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/jobs/jobexecutor.cxx b/framework/source/jobs/jobexecutor.cxx
index 6b133a5c219d..54fe8469ae08 100644
--- a/framework/source/jobs/jobexecutor.cxx
+++ b/framework/source/jobs/jobexecutor.cxx
@@ -75,7 +75,7 @@ DEFINE_INIT_SERVICE( JobExecutor,
/*Attention
I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
to create a new instance of this class by our own supported service factory.
- see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further informations!
+ see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
*/
// read the list of all currently registered events inside configuration.
// e.g. "/org.openoffice.Office.Jobs/Events/<event name>"
@@ -120,7 +120,7 @@ JobExecutor::JobExecutor( /*IN*/ const css::uno::Reference< css::lang::XMultiSer
, m_aConfig (comphelper::getComponentContext(xSMGR), OUString::createFromAscii(JobData::EVENTCFG_ROOT) )
{
// Don't do any reference related code here! Do it inside special
// impl_ method() ... see DEFINE_INIT_SERVICE() macro for further informations.
}
JobExecutor::~JobExecutor()
@@ -120,7 +120,7 @@ JobExecutor::JobExecutor( /*IN*/ const css::uno::Reference< css::lang::XMultiSer
{
// Don't do any reference related code here! Do it inside special
- // impl_ method() ... see DEFINE_INIT_SERVICE() macro for further informations.
+ // impl_ method() ... see DEFINE_INIT_SERVICE() macro for further information.
}
JobExecutor::~JobExecutor()